@@ -1,8 +1,13 @@
 from requests.exceptions import TooManyRedirects
 
+
+DEFAULT_REDIRECT_KEY_PREFIX = 'redirect'
+DEFAULT_REDIRECT_MAX_AGE = 60 * 60 * 24 * 365 * 10       # 10 years
+
+
 class RedirectManager(object):
 
-    def __init__(self, key_prefix, cache):
+    def __init__(self, cache, key_prefix=DEFAULT_REDIRECT_KEY_PREFIX):
         self.key_prefix = key_prefix
         self.cache = cache
 
@@ -10,6 +15,9 @@ class RedirectManager(object):
         return '%s.%s' % (self.key_prefix, url)
 
     def process_request(self, request):
+        if self.cache is None:
+            return
+
         url = request.url
         history = []
         while True:
@@ -22,10 +30,13 @@ class RedirectManager(object):
         request.url = url
 
     def process_response(self, request, response):
+        if self.cache is None:
+            return
+
         if response.history:
             request.url = response.url
             for r in response.history:
                 if r.status_code == 301:
                     #TODO: handle case of no Location header
                     redirect_to = r.headers.get('Location')
-                    self.cache.set(self.get_cache_key(r.url), redirect_to)
+                    self.cache.set(self.get_cache_key(r.url), redirect_to, DEFAULT_REDIRECT_MAX_AGE)
